Index: main/waeup.sirp/trunk/src/waeup/sirp/image/README.txt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/README.txt	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/README.txt	(revision 7321)
@@ -2,8 +2,8 @@
 ========================================
 
-The image file widget is built on top of the :class:`WAeUPImageFile` object::
-
-  >>> from waeup.sirp.image import WAeUPImageFile
-  >>> file = WAeUPImageFile('foo.jpg', 'mydata')
+The image file widget is built on top of the :class:`SIRPImageFile` object::
+
+  >>> from waeup.sirp.image import SIRPImageFile
+  >>> file = SIRPImageFile('foo.jpg', 'mydata')
   >>> file.filename
   'foo.jpg'
@@ -16,5 +16,5 @@
   'mydata'
 
-We can also create WAeUPImageFile objects from file-like objects::
+We can also create SIRPImageFile objects from file-like objects::
 
   >>> from StringIO import StringIO
@@ -36,5 +36,5 @@
 ----------------
 
-The WAeUPImageFile object normally stores the file data using ZODB
+The SIRPImageFile object normally stores the file data using ZODB
 persistence. Files can however also be stored by tramline.  If
 tramline is installed in Apache, the Tramline takes care of generating
@@ -73,5 +73,5 @@
 just '1') will now be created::
 
-  >>> file = WAeUPImageFile('foo.jpg', '1')
+  >>> file = SIRPImageFile('foo.jpg', '1')
 
 The data is now '1', referring to the real file::
@@ -102,5 +102,5 @@
 We expect the same behavior as when tramline is not installed::
 
-  >>> file = WAeUPImageFile('foo.jpg', 'data')
+  >>> file = SIRPImageFile('foo.jpg', 'data')
   >>> f = file.file
   >>> f.read()
@@ -141,12 +141,12 @@
   Traceback (most recent call last):
   ...
-  WrongType: ('asd', <class 'waeup.sirp.image.image.WAeUPImageFile'>, 'foo')
+  WrongType: ('asd', <class 'waeup.sirp.image.image.SIRPImageFile'>, 'foo')
 
 which means: `ImageFile` fields should better contain
-:class:`WAeUPImageFile` instances.
-
-We can store normal :class:`WAeUPImageFile` instances:
-
-  >>> field.validate(WAeUPImageFile('bar.jpg', 'data')) is None
+:class:`SIRPImageFile` instances.
+
+We can store normal :class:`SIRPImageFile` instances:
+
+  >>> field.validate(SIRPImageFile('bar.jpg', 'data')) is None
   True
 
@@ -173,9 +173,9 @@
 
   >>> field.validate(
-  ...     WAeUPImageFile('bar.jpg', '123456789012')) is None
-  True
-
-  >>> field.validate(
-  ...     WAeUPImageFile('bar.jpg', '12345')) is None
+  ...     SIRPImageFile('bar.jpg', '123456789012')) is None
+  True
+
+  >>> field.validate(
+  ...     SIRPImageFile('bar.jpg', '12345')) is None
   True
 
@@ -183,5 +183,5 @@
 
   >>> field.validate(
-  ...     WAeUPImageFile('bar.jpg', '1234567890123'))
+  ...     SIRPImageFile('bar.jpg', '1234567890123'))
   Traceback (most recent call last):
   ...
@@ -189,5 +189,5 @@
 
   >>> field.validate(
-  ...     WAeUPImageFile('bar.jpg', '1234'))
+  ...     SIRPImageFile('bar.jpg', '1234'))
   Traceback (most recent call last):
   ...
@@ -198,10 +198,10 @@
 ----------------------------
 
-WAeUPImageFile does not reproduce the broken unequal comparison from
+SIRPImageFile does not reproduce the broken unequal comparison from
 its base:
 
-  >>> f1 = WAeUPImageFile('bar.jpg', '123456789')
-  >>> f2 = WAeUPImageFile('bar.jpg', '123456789')
-  >>> f3 = WAeUPImageFile('baz.jpg', '1234')
+  >>> f1 = SIRPImageFile('bar.jpg', '123456789')
+  >>> f2 = SIRPImageFile('bar.jpg', '123456789')
+  >>> f3 = SIRPImageFile('baz.jpg', '1234')
   >>> f1 == f2
   True
Index: main/waeup.sirp/trunk/src/waeup/sirp/image/__init__.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/__init__.py	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/__init__.py	(revision 7321)
@@ -3,8 +3,8 @@
 Includings schemas, widgets and the content components.
 """
-from waeup.sirp.image.image import WAeUPImageFile, createWAeUPImageFile
+from waeup.sirp.image.image import SIRPImageFile, createSIRPImageFile
 
 __all__ = [
-    "WAeUPImageFile",
-    "createWAeUPImageFile",
+    "SIRPImageFile",
+    "createSIRPImageFile",
     ]
Index: main/waeup.sirp/trunk/src/waeup/sirp/image/browser/tests/image.txt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/browser/tests/image.txt	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/browser/tests/image.txt	(revision 7321)
@@ -12,8 +12,8 @@
 
   >>> import os
-  >>> from waeup.sirp.image import WAeUPImageFile
+  >>> from waeup.sirp.image import SIRPImageFile
   >>> testimage = os.path.join(os.path.dirname(__file__), 'sample.jpg')
   >>> testimage2 = os.path.join(os.path.dirname(__file__), 'sample2.jpg')
-  >>> some_file = WAeUPImageFile('foo.jpg', open(testimage, 'rb').read())
+  >>> some_file = SIRPImageFile('foo.jpg', open(testimage, 'rb').read())
   >>> some_file.filename
   'foo.jpg'
@@ -166,5 +166,5 @@
 prepare some new file:
 
-  >>> another_file = WAeUPImageFile('bar.txt', 'bar contents')
+  >>> another_file = SIRPImageFile('bar.txt', 'bar contents')
 
 We happen to know, due to the implementation of
@@ -200,5 +200,5 @@
 ---------------------------
 
-As :class:`waeup.sirp.image.WAeUPImageFile` objects support storing
+As :class:`waeup.sirp.image.SIRPImageFile` objects support storing
 image data by using external 'storages', also our widgets should do
 so.
@@ -220,5 +220,5 @@
   ...         contents = f.read()
   ...         id_string = hashlib.md5(contents).hexdigest()
-  ...         result = WAeUPImageFile(filename, id_string)
+  ...         result = SIRPImageFile(filename, id_string)
   ...         self.storage[id_string] = contents
   ...         return result
@@ -260,9 +260,9 @@
 We now want to simulate, that the field contains already data,
 identified by some `file_id`. To do so, we first store the data in our
-file retrieval and then create a WAeUPImageFile object with that
+file retrieval and then create a SIRPImageFile object with that
 file_id stored:
 
-  >>> from waeup.sirp.image import createWAeUPImageFile
-  >>> image = createWAeUPImageFile(
+  >>> from waeup.sirp.image import createSIRPImageFile
+  >>> image = createSIRPImageFile(
   ...     'sample.jpg', open(testimage, 'rb'))
   >>> file_id = image.data
@@ -274,5 +274,5 @@
   '9feac4265077922000aa8b88748e25be'
 
-The new file was stored by our utility, as createWAeUPImageFile looks
+The new file was stored by our utility, as createSIRPImageFile looks
 up IFileRetrieval utilities and uses them:
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/image/browser/widget.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/browser/widget.py	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/browser/widget.py	(revision 7321)
@@ -19,5 +19,5 @@
 """
 import os
-from waeup.sirp.image import WAeUPImageFile
+from waeup.sirp.image import SIRPImageFile
 from hurry.file.browser.widget import (
     EncodingFileWidget, DownloadWidget, FakeFieldStorage)
@@ -62,5 +62,5 @@
                 seek(0)
                 return retrieval.createFile(input.filename, input)
-            return WAeUPImageFile(input.filename, data)
+            return SIRPImageFile(input.filename, data)
         else:
             return self.context.missing_value
@@ -143,5 +143,5 @@
         data = file_id.decode('base64')
         filename, filedata = data.split('\n', 1)
-        return WAeUPImageFile(filename, filedata)
+        return SIRPImageFile(filename, filedata)
 
 class ThumbnailWidget(DownloadWidget):
Index: main/waeup.sirp/trunk/src/waeup/sirp/image/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/interfaces.py	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/interfaces.py	(revision 7321)
@@ -24,5 +24,5 @@
     """
     
-class IWAeUPImageFile(IHurryFile):
+class ISIRPImageFile(IHurryFile):
     """Image file.
     """
Index: main/waeup.sirp/trunk/src/waeup/sirp/image/schema.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/schema.py	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/schema.py	(revision 7321)
@@ -23,5 +23,5 @@
 from hurry.file.schema import File
 from waeup.sirp.image.interfaces import IImageFile
-from waeup.sirp.image.image import WAeUPImageFile
+from waeup.sirp.image.image import SIRPImageFile
 
 class MinMaxSize(object):
@@ -82,3 +82,3 @@
     implements(IImageFile)
 
-    _type = WAeUPImageFile
+    _type = SIRPImageFile

Index: main/waeup.sirp/trunk/src/waeup/sirp/image/image.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/image/image.py	(revision 7196)
+++ main/waeup.sirp/trunk/src/waeup/sirp/image/image.py	(revision 7321)
@@ -23,7 +23,7 @@
 from zope.component import getUtility
 from zope.interface import implements
-from waeup.sirp.image.interfaces import IWAeUPImageFile
+from waeup.sirp.image.interfaces import ISIRPImageFile
 
-class WAeUPImageFile(HurryFile):
+class SIRPImageFile(HurryFile):
     """A file prepared for storing image files.
 
@@ -32,8 +32,8 @@
     regular hurry files.
 
-    To create a :class:`WAeUPImageFile` you should use
-    :func:`createWAeUPImageFile`.
+    To create a :class:`SIRPImageFile` you should use
+    :func:`createSIRPImageFile`.
     """
-    implements(IWAeUPImageFile)
+    implements(ISIRPImageFile)
 
     def __ne__(self, other):
@@ -45,5 +45,5 @@
             return True
 
-def createWAeUPImageFile(filename, f):
+def createSIRPImageFile(filename, f):
     retrieval = getUtility(IFileRetrieval)
     return retrieval.createFile(filename, f)